==> znuny_6.4.2.orig.tar.gz: Znuny-rel-6_4_2/README.md <==
<a href="https://www.znuny.org"><img align="center" src="https://github.com/znuny/Znuny/blob/rel-6_4/var/httpd/htdocs/skins/Agent/default/img/logo.png"></a>

<p align="center">
    <a href="https://download.znuny.org/releases/znuny-latest.tar.gz"><img src="https://img.shields.io/github/v/tag/znuny/Znuny?label=latest%20release"></a>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://img.shields.io/github/workflow/status/znuny/Znuny/CI?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA4AAAAOCAMAAAAolt3jAAAABGdBTUEAALGPC/xhBQAAACBjSFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAABv1BMVEUAAAD+9OfyjQb1pz3////4xH7qSgD3vG3vdgD61KL1q0j0oC/uagD2r1D3vnD2s1n3uWX4v3PnMAD2s1j1pj32rk7uaQD4xoL3u2r4xYD62KjucAD86c/3uWX1pTv0oTH0nyz0ojT1qUH3vW/85MT1pjz0nivzmSDzmB3zmB3zmiH0ny31q0f////1qULzmyPzmyP1pDf5zpP0ojT0nSf2sVT2slf0oTDzmR70ozb3u2v0pDfzmiH0nCX3tV35z5X1pz7zmiLzmiL1qkX3uGT0nSjzmiL1qUP4xH30pDbzmB70nCb3t2D60p30ojPzmR/0oTL5x4P0ozXzmiHzmyT1rEr2tFr0nSfzmyT1pz/4xYD1pz70nCfzmB7zmR/0nir1qD/86tH////2rk70ozX0oC/0nSf0oTH1pjz3t2HzlxzzlxvzlxvzlxvzlxvzlxvzlxvzlxvzmBzzlxvzlxvzlxvzlxvzlxvzlxvzlxvzlxvzmB3zlxvzlxvzlxvzlxvzlxvzlxvzlxvzlxvzlxvzlxvzlxvzmBzzlxvzlxvzlxvzlxrzlxvzlxvzlxvzlxvzlxvzlxzzlxvzlxz///8zTegBAAAAanRSTlMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA9DdYRxPAsCQrnx/v3tqjQBYOraQAqk0CIZnfp+DH7yvw0EX+ncIA/A3SEIiPrGEQV394cDa/TbKy3f6lYGW83598JGAgAbXpWgkVYVWK32+wAAAAFiS0dEBI9o2VEAAAAHdElNRQflAxcGEwaMMq1yAAAAxklEQVQI12NgYGSSlZNXUFRSZmZhYGBgVVFVU9fI0tTS1mFjZ2DQ1dPPzsnNyy8oNDDk4GQwMi4qLikFgrJyE1MuBm4zc4uKShC/qtqSh4GB18rapgbEray1tQMaxmfv4FgH4tc7OQO5DPwurg0gbqObO5An4OHp1QTkNbd4+zAwCPr6+beCzG5rDxBiEA4MCu4A8Tq7QkJFGETDwrt7ekv7+idERIqJM0hERcfETpw0OS4+IVESaJJUUnJKalp6Rqa0DAMDAAI8OSF3w4d/AAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDIxLTAzLTIzVDA2OjE5OjA2KzAwOjAwu7i+QwAAACV0RVh0ZGF0ZTptb2RpZnkAMjAyMS0wMy0yM1QwNjoxOTowNiswMDowMMrlBv8AAAAZdEVYdFNvZnR3YXJlAEFkb2JlIEltYWdlUmVhZHlxyWU8AAAAAElFTkSuQmCC&label=CI"></a>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://badge.proxy.znuny.com/Znuny/rel-6_4"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/issues"><img src="https://img.shields.io/github/issues-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/issues?q=is%3Aissue+is%3Aclosed"><img src="https://img.shields.io/github/issues-closed-raw/znuny/Znuny?color=#44CC44"></a>
    <a href="https://github.com/znuny/Znuny/pulls"><img src="https://img.shields.io/github/issues-pr-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/pulls?q=is%3Apr+is%3Aclosed"><img src="https://img.shields.io/github/issues-pr-closed-raw/znuny/Znuny?color=brightgreen"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/graphs/contributors"><img src="https://img.shields.io/github/contributors/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny"><img src="https://img.shields.io/github/languages/count/znuny/Znuny?style=flat&label=language"></a>
    <br>
    <a href="https://discord.gg/XTud3WWZTs"><img src="https://img.shields.io/discord/836533233885773825?style=flat"></a>
</p>
<hr>

Znuny
=======
Znuny is a continuation of the ((OTRS)) Community Edition (version 6.0.30) which was declared end of life (EOL) at the end of December 2020.

The primary goal for this project is to provide a maintained and stable version of the well known ticket system and improve it with new features.

The second goal is to reestablish a connection to the community.

License
=======
The project is distributed under the GNU General Public License (GPL v3) - see the accompanying [COPYING](COPYING) file for general license information.
If you need more details you can have a look [here](https://snyk.io/learn/what-is-gpl-license-gplv3-explained/).

Documentation
=============
You can find documentation [here](https://doc.znuny.org/).
The source code of Znuny is publicly available on [GitHub](https://github.com/znuny/znuny).

You want to get in touch?
- [Project website](https://www.znuny.org)
- [Community forum](https://community.znuny.org)
- [Discord Server](https://discord.gg/XTud3WWZTs)
- [Commercial services](https://www.znuny.com)

Software requirements
=====================
Operating system
- Linux (Debian or Red Hat preferred)
- Perl 5.16.0 or higher

Web server
- Apache 2 + mod_perl2 or higher (recommended)
- Web server with CGI support (CGI is not recommended)

Databases
- MySQL 5.0 or higher
- MariaDB
- PostgreSQL 9.2 or higher
- Oracle 10g or higher

Browsers
- These browsers are NOT supported:
  - Internet Explorer before version 11
  - Firefox before version 31
  - Safari before version 6

Vendor
=======
This project is mainly funded by Znuny GmbH, Berlin.
If you need professional support or consulting, feel free to contact us.

[Znuny Website](https://www.znuny.com)

==> znuny_6.4.5.orig.tar.gz: Znuny-rel-6_4_5/README.md <==
<a href="https://www.znuny.org"><img align="center" src="https://github.com/znuny/Znuny/blob/rel-6_4/var/httpd/htdocs/skins/Agent/default/img/logo.png"></a>

<p align="center">
    <a href="https://download.znuny.org/releases/znuny-latest.tar.gz"><img src="https://img.shields.io/github/v/tag/znuny/Znuny?sort=semver&label=latest%20release&color=ff9b00"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://img.shields.io/github/workflow/status/znuny/Znuny/CI?label=CI&color=brightgreen"></a>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://badge.proxy.znuny.com/Znuny/rel-6_4"></a>
    <a href="https://translations.znuny.org/engage/znuny/"><img src="https://translations.znuny.org/widgets/znuny/-/znuny/svg-badge.svg" alt="Translation status"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/issues"><img src="https://img.shields.io/github/issues-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/issues?q=is%3Aissue+is%3Aclosed"><img src="https://img.shields.io/github/issues-closed-raw/znuny/Znuny?color=#44CC44"></a>
    <a href="https://github.com/znuny/Znuny/pulls"><img src="https://img.shields.io/github/issues-pr-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/pulls?q=is%3Apr+is%3Aclosed"><img src="https://img.shields.io/github/issues-pr-closed-raw/znuny/Znuny?color=brightgreen"></a>
    <br>
    <a href="https://github.com/znuny/Znuny"><img src="https://img.shields.io/github/languages/count/znuny/Znuny?style=flat&label=language&color=brightgreen"></a>
    <a href="https://github.com/znuny/Znuny/graphs/contributors"><img src="https://img.shields.io/github/contributors/znuny/Znuny?"></a>
    <a href="https://discord.gg/XTud3WWZTs"><img src="https://img.shields.io/discord/836533233885773825?style=flat"></a>
</p>
<hr>

Znuny
=======
Znuny is a continuation of the ((OTRS)) Community Edition (version 6.0.30) which was declared end of life (EOL) at the end of December 2020.

The primary goal for this project is to provide a maintained and stable version of the well known ticket system and improve it with new features.

The second goal is to reestablish a connection to the community.

License
=======
The project is distributed under the GNU General Public License (GPL v3) - see the accompanying [COPYING](COPYING) file for general license information.
If you need more details you can have a look [here](https://snyk.io/learn/what-is-gpl-license-gplv3-explained/).

Documentation
=============
You can find documentation [here](https://doc.znuny.org/).
The source code of Znuny is publicly available on [GitHub](https://github.com/znuny/znuny).

You want to get in touch?
- [Project website](https://www.znuny.org)
- [Community forum](https://community.znuny.org)
- [Discord Server](https://discord.gg/XTud3WWZTs)
- [Commercial services](https://www.znuny.com)

Software requirements
=====================
Operating system
- Linux (Debian or Red Hat preferred)
- Perl 5.16.0 or higher

Web server
- Apache 2 + mod_perl2 or higher (recommended)
- Web server with CGI support (CGI is not recommended)

Databases
- MySQL 5.0 or higher
- MariaDB
- PostgreSQL 9.2 or higher
- Oracle 10g or higher

Browsers
- These browsers are NOT supported:
  - Internet Explorer before version 11
  - Firefox before version 31
  - Safari before version 6

Vendor
=======
This project is mainly funded by Znuny GmbH, Berlin.
If you need professional support or consulting, feel free to contact us.

[Znuny Website](https://www.znuny.com)
